@@ -5,10 +5,7 @@ use crate::PublishNotification;
 use core::convert::TryInto;
 use core::ops::Add;
 use embedded_time::duration::Milliseconds;
-use heapless::{
-    pool,
-    pool::singleton::Pool,
-};
+use heapless::{pool, pool::singleton::Pool};
 use heapless::{FnvIndexMap, FnvIndexSet, IndexMap, IndexSet};
 use mqttrust::encoding::v4::*;
 
